@@ -23,15 +23,15 @@ use tide::{
 };
 
 #[cfg(feature = "websocket")]
-pub use subscription::Subscription;
+pub use subscription::GraphQLSubscription;
 
 /// Create a new GraphQL endpoint with the schema.
 ///
 /// Default multipart options are used and batch operations are supported.
-pub fn endpoint<Query, Mutation, Subscription>(
+pub fn graphql<Query, Mutation, Subscription>(
     schema: Schema<Query, Mutation, Subscription>,
-) -> Endpoint<Query, Mutation, Subscription> {
-    Endpoint {
+) -> GraphQLEndpoint<Query, Mutation, Subscription> {
+    GraphQLEndpoint {
         schema,
         opts: MultipartOptions::default(),
         batch: true,
@@ -42,7 +42,7 @@ pub fn endpoint<Query, Mutation, Subscription>(
 ///
 /// This is created with the [`endpoint`](fn.endpoint.html) function.
 #[non_exhaustive]
-pub struct Endpoint<Query, Mutation, Subscription> {
+pub struct GraphQLEndpoint<Query, Mutation, Subscription> {
     /// The schema of the endpoint.
     pub schema: Schema<Query, Mutation, Subscription>,
     /// The multipart options of the endpoint.
@@ -51,7 +51,7 @@ pub struct Endpoint<Query, Mutation, Subscription> {
     pub batch: bool,
 }
 
-impl<Query, Mutation, Subscription> Endpoint<Query, Mutation, Subscription> {
+impl<Query, Mutation, Subscription> GraphQLEndpoint<Query, Mutation, Subscription> {
     /// Set the multipart options of the endpoint.
     #[must_use]
     pub fn multipart_opts(self, opts: MultipartOptions) -> Self {
@@ -65,7 +65,7 @@ impl<Query, Mutation, Subscription> Endpoint<Query, Mutation, Subscription> {
 }
 
 // Manual impl to remove bounds on generics
-impl<Query, Mutation, Subscription> Clone for Endpoint<Query, Mutation, Subscription> {
+impl<Query, Mutation, Subscription> Clone for GraphQLEndpoint<Query, Mutation, Subscription> {
     fn clone(&self) -> Self {
         Self {
             schema: self.schema.clone(),
@@ -77,7 +77,7 @@ impl<Query, Mutation, Subscription> Clone for Endpoint<Query, Mutation, Subscrip
 
 #[async_trait]
 impl<Query, Mutation, Subscription, TideState> tide::Endpoint<TideState>
-    for Endpoint<Query, Mutation, Subscription>
+    for GraphQLEndpoint<Query, Mutation, Subscription>
 where
     Query: ObjectType + 'static,
     Mutation: ObjectType + 'static,
